summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderindex.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolderindex.h')
-rw-r--r--kmail/kmfolderindex.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kmail/kmfolderindex.h b/kmail/kmfolderindex.h
index 2762d143d..b08508955 100644
--- a/kmail/kmfolderindex.h
+++ b/kmail/kmfolderindex.h
@@ -37,23 +37,24 @@
class KMFolderIndex: public FolderStorage
{
Q_OBJECT
+ TQ_OBJECT
//TODO:Have to get rid of this friend declaration and add necessary pure
//virtuals to kmfolder.h so that KMMsgBase::parent() can be a plain KMFolder
//rather than a KMFolderIndex. Need this for database indices.
friend class ::KMMsgBase;
public:
/** This enum indicates the status of the index file. It's returned by
- indexStatus().
+ indextqStatus().
*/
- enum IndexStatus { IndexOk,
+ enum IndextqStatus { IndexOk,
IndexMissing,
IndexCorrupt,
IndexTooOld
};
- /** Usually a parent is given. But in some cases there is no
- fitting parent object available. Then the name of the folder
+ /** Usually a tqparent is given. But in some cases there is no
+ fitting tqparent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderIndex(KMFolder* folder, const char* name=0);
virtual ~KMFolderIndex();
@@ -67,8 +68,8 @@ public:
virtual const KMMsgBase* getMsgBase(int idx) const { return mMsgList[idx]; }
virtual KMMsgBase* getMsgBase(int idx) { return mMsgList[idx]; }
- virtual int find(const KMMsgBase* msg) const { return mMsgList.find((KMMsgBase*)msg); }
- int find( const KMMessage * msg ) const { return FolderStorage::find( msg ); }
+ virtual int tqfind(const KMMsgBase* msg) const { return mMsgList.tqfind((KMMsgBase*)msg); }
+ int tqfind( const KMMessage * msg ) const { return FolderStorage::tqfind( msg ); }
/** Registered unique serial number for the index file */
int serialIndexId() const { return mIndexId; }
@@ -90,7 +91,7 @@ public:
Should return IndexOk if the folder doesn't exist anymore "physically"
or if the index is not older than the contents.
*/
- virtual IndexStatus indexStatus() = 0;
+ virtual IndextqStatus indextqStatus() = 0;
public slots:
/** Incrementally update the index if possible else call writeIndex */
@@ -37,23 +37,24 @@
//TODO:Have to get rid of this friend declaration and add necessary pure
- //virtuals to kmfolder.h so that KMMsgBase::parent() can be a plain KMFolder
+ //virtuals to kmfolder.h so that KMMsgBase::tqparent() can be a plain KMFolder
//rather than a KMFolderIndex. Need this for database indices.
friend class ::KMMsgBase;